@@ -1,4 +1,4 @@
-# Copyright (c) 2012 gocept gmbh & co. kg
+# Copyright (c) gocept gmbh & co. kg
 # See also LICENSE.txt
 
 from .check import Check
@@ -11,7 +11,7 @@ from .multiarg import MultiArg
 from .performance import Performance
 from .range import Range
 from .resource import Resource
-from .result import Result, ScalarResult, Results
+from .result import Result, Results
 from .runtime import Runtime, guarded
 from .state import Ok, Warn, Critical, Unknown
 from .summary import Summary
