@@ -17,14 +17,12 @@ evaluation or performance data logic.
 
 from .performance import Performance
 from .range import Range
-from .result import Result, ScalarResult
+from .result import Result
 from .state import Ok, Warn, Critical
 
 
 class Context(object):
 
-    fmt_metric = '{name} is {valueunit}'
-
     def __init__(self, name, fmt_metric=None, result_cls=Result):
         """Creates generic context identified by `name`.
 
@@ -43,8 +41,7 @@ class Context(object):
             evaluation outcome
         """
         self.name = name
-        if fmt_metric is not None:
-            self.fmt_metric = fmt_metric
+        self.fmt_metric = fmt_metric
         self.result_cls = result_cls
 
     def evaluate(self, metric, resource):
@@ -81,13 +78,18 @@ class Context(object):
         Formats the metric according to the :attr:`fmt_metric`
         attribute. If :attr:`fmt_metric` is a string, it is evaluated as
         format string with all metric attributes in the root namespace.
-        The default is the interpolated string "`{name} is
-        {valueunit}`". If :attr:`fmt_metric` is callable, it is called
-        with the metric and this context as arguments.
+        If :attr:`fmt_metric` is callable, it is called with the metric
+        and this context as arguments. If :attr:`fmt_metric` is not set,
+        this default implementation does not return a description.
 
-        :param metric: associated metric that must be formatted
-        :returns: description string
+        Plugin authors may override this method in subclasses to control
+        text output more tightly.
+
+        :param metric: associated metric
+        :returns: description string or None
         """
+        if not self.fmt_metric:
+            return
         try:
             return self.fmt_metric(metric, self)
         except TypeError:
@@ -98,8 +100,8 @@ class Context(object):
 
 class ScalarContext(Context):
 
-    def __init__(self, name, warning, critical, fmt_metric=None,
-                 result_cls=ScalarResult):
+    def __init__(self, name, warning=None, critical=None,
+                 fmt_metric='{name} is {valueunit}', result_cls=Result):
         """Ready-to-use :class:`Context` subclass for scalar values.
 
         ScalarContext models the common case where a single scalar is to
@@ -122,16 +124,18 @@ class ScalarContext(Context):
 
         The metric's value is compared to the instance's :attr:`warning`
         and :attr:`critical` ranges, yielding an appropropiate state
-        depending on how the metric fits in the ranges.
+        depending on how the metric fits in the ranges. Plugin authors
+        may override this method in subclasses to provide custom
+        evaluation logic.
 
         :param metric: metric that is to be evaluated
         :param resource: not used
         :returns: :class:`~nagiosplugin.result.Result` object
         """
         if not self.critical.match(metric.value):
-            return self.result_cls(Critical, self.critical, metric)
+            return self.result_cls(Critical, self.critical.violation, metric)
         elif not self.warning.match(metric.value):
-            return self.result_cls(Warn, self.warning, metric)
+            return self.result_cls(Warn, self.warning.violation, metric)
         else:
             return self.result_cls(Ok, None, metric)
 
