@@ -2,10 +2,16 @@
 # Copyright (c) gocept gmbh & co. kg
 # See also LICENSE.txt
 
+from __future__ import unicode_literals, print_function
 from nagiosplugin.cookie import Cookie
-import unittest
-import tempfile
+import codecs
 import os
+import tempfile
+
+try:
+    import unittest2 as unittest
+except ImportError:  # pragma: no cover
+    import unittest
 
 
 class CookieTest(unittest.TestCase):
@@ -32,6 +38,7 @@ class CookieTest(unittest.TestCase):
             c['foo']
 
     def test_exit_should_write_content(self):
+        os.unlink(self.tf.name)
         with Cookie(self.tf.name) as c:
             c['hello'] = 'wörld'
         with open(self.tf.name) as f:
@@ -75,22 +82,36 @@ class CookieTest(unittest.TestCase):
     def test_corrupted_cookie_should_raise(self):
         with open(self.tf.name, 'w') as f:
             f.write('{{{')
+        c = Cookie(self.tf.name)
         with self.assertRaises(ValueError):
-            with Cookie(self.tf.name):
-                pass
+            c.open()
+        c.close()
 
     def test_wrong_cookie_format(self):
         with open(self.tf.name, 'w') as f:
             f.write('[1, 2, 3]\n')
+        c = Cookie(self.tf.name)
         with self.assertRaises(ValueError):
-            with Cookie(self.tf.name):
-                pass
+            c.open()
+        c.close()
 
     def test_cookie_format_exception_truncates_file(self):
-        with open(self.tf.name, 'w') as f:
+        with codecs.open(self.tf.name, 'w', 'utf-8') as f:
             f.write('{slö@@ä')
+        c = Cookie(self.tf.name)
         try:
-            with Cookie(self.tf.name):
-                pass
+            c.open()
         except ValueError:
-            self.assertEqual(0, os.stat(self.tf.name).st_size)
+            pass
+        finally:
+            c.close()
+        self.assertEqual(0, os.stat(self.tf.name).st_size)
+
+    def test_oblivious_cookie(self):
+        c = Cookie('')
+        # the following method calls are not expected to perfom any function
+        c.open()
+        c['key'] = 1
+        c.commit()
+        c.close()
+        self.assertEqual(c['key'], 1)
