@@ -1,13 +1,17 @@
-# Copyright (c) 2012 gocept gmbh & co. kg
+# Copyright (c) gocept gmbh & co. kg
 # See also LICENSE.txt
 
 import pkg_resources
 import re
 import subprocess
 import sys
-import unittest
 import os.path as p
 
+try:
+    import unittest2 as unittest
+except ImportError:  # pragma: no cover
+    import unittest
+
 
 class ExamplesTest(unittest.TestCase):
     base = p.normpath(p.join(p.dirname(p.abspath(__file__)), '..', '..'))
@@ -17,15 +21,17 @@ class ExamplesTest(unittest.TestCase):
             sys.executable, pkg_resources.resource_filename(
                 'nagiosplugin.examples', program), '-v'],
             stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE, env={'PYTHONPATH': self.base})
+            stderr=subprocess.PIPE, env={'PYTHONPATH': ':'.join(sys.path)})
         out, err = proc.communicate()
         self.assertEqual(err.decode(), '')
         self.assertTrue(re.match(regexp, out.decode()) is not None,
-                        '"{}" does not match "{}"'.format(
+                        '"{0}" does not match "{1}"'.format(
                             out.decode(), regexp))
         self.assertEqual(0, proc.returncode)
 
     def test_check_load(self):
+        if not sys.platform.startswith('linux'):  # pragma: no cover
+            self.skipTest('requires Linux')
         self._run_example('check_load.py', """\
 LOAD OK - loadavg is [0-9., ]+
 | load15=[0-9.]+;;;0 load1=[0-9.]+;;;0 load5=[0-9.]+;;;0
