@@ -1,11 +1,15 @@
-# Copyright (c) 2012 gocept gmbh & co. kg
+# Copyright (c) gocept gmbh & co. kg
 # See also LICENSE.txt
 
 from nagiosplugin.platform import with_timeout
 import nagiosplugin
-import unittest
 import time
 
+try:
+    import unittest2 as unittest
+except ImportError:  # pragma: no cover
+    import unittest
+
 
 class PlatformTest(unittest.TestCase):
 
